# Table of Contents

- [authorization-model](<./authorization-model.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Authorization Model](<./Authorization-Model.md>)
  - [Overview](<./Authorization-Model/Overview.md>)
  - [Terminology](<./Authorization-Model/Terminology.md>)
  - [Fact Sheet Attributes](<./Authorization-Model/Fact-Sheet-Attributes.md>)
  - [Common Use Case: Hide Costs](<./Authorization-Model/Common-Use-Case-Hide-Costs.md>)
  - [Fact Sheet Type Level](<./Authorization-Model/Fact-Sheet-Type-Level.md>)
  - [Subscription Type Check](<./Authorization-Model/Subscription-Type-Check.md>)
  - [Saved Searches](<./Authorization-Model/Saved-Searches.md>)
  - [Granular Access](<./Authorization-Model/Granular-Access.md>)
  - [Summary of Functionality](<./Authorization-Model/Summary-of-Functionality.md>)
  - [Routines](<./Authorization-Model/Routines.md>)
  - [Fact Sheet Specific](<./Authorization-Model/Fact-Sheet-Specific.md>)
  - [Administration Area Functionality](<./Authorization-Model/Administration-Area-Functionality.md>)
  - [Dashboards](<./Authorization-Model/Dashboards.md>)
  - [Was this page helpful?](<./Authorization-Model/Was-this-page-helpful.md>)
